@@ -19,7 +19,6 @@ package api
 import (
 	"context"
 	"fmt"
-	"io"
 	"strings"
 	"time"
 
@@ -59,7 +58,7 @@ type Service interface {
 	// RunOneOffContainer creates a service oneoff container and starts its dependencies
 	RunOneOffContainer(ctx context.Context, project *types.Project, opts RunOptions) (int, error)
 	// Remove executes the equivalent to a `compose rm`
-	Remove(ctx context.Context, project *types.Project, options RemoveOptions) error
+	Remove(ctx context.Context, project string, options RemoveOptions) error
 	// Exec executes a command in a running service container
 	Exec(ctx context.Context, project string, opts RunOptions) (int, error)
 	// Copy copies a file/folder between a service container and the local filesystem
@@ -216,9 +215,6 @@ type RunOptions struct {
 	Entrypoint        []string
 	Detach            bool
 	AutoRemove        bool
-	Stdin             io.ReadCloser
-	Stdout            io.WriteCloser
-	Stderr            io.WriteCloser
 	Tty               bool
 	WorkingDir        string
 	User              string
